/*
 * Copyright (c) 1996, 2003 VIA Networking Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    This product includes software developed by VIA Networking Technologies, Inc.
 * 4. Neither the name of the Company nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY VIA NETWORKING TECHNOLOGIES, INC. AND 
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, 
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL 
 * VIA NETWORKING TECHNOLOGIES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *
 * File: if_getb_cfg.h
 *
 * Purpose: Driver configuration header file
 *
 * Author: Ryan Fu
 *
 * Date: Jul 22, 2003
 *
 *
 */

#ifndef __IF_GETB_CFG_H__
#define __IF_GETB_CFG_H__

/*
 *  Options for driver
 */
#define TX_DESC_NUM_DEF     (64)      
#define RX_DESC_NUM_DEF     (64)        /*must be 4X*/
#define SPEED_DUPLEX_DEF    (0)
#define DMA_LENGTH_DEF      (1)         
#define RX_THRESH_DEF       (0)         
#define FLOW_CNTL_DEF       (1)
#define VAL_PKTLEN_DEF      (0)
#define INT_WORKS_DEF       (10)



typedef unsigned char   UCHAR,  *PUCHAR;
typedef unsigned short  U16,    *PU16;
typedef unsigned char   UINT8,  *PUINT8;
typedef unsigned long   U32,    *PU32;
typedef unsigned long   UINT32, *PUINT32;
typedef unsigned int    UINT,   *PUINT;
typedef unsigned char   BYTE,   *PBYTE;
typedef unsigned char   U8,     *PU8;
typedef U32             BOOL,   *PBOOL;
typedef U16             WORD,   *PWORD;
typedef U32             DWORD,  *PDWORD;
typedef unsigned long   ULONG,  *PULONG;


#ifndef FALSE
#define FALSE   (0)
#endif

#ifndef TRUE
#define TRUE    (!(FALSE))
#endif


#define GETB_NAME           "if_getb"
#define GETB_FULL_DRV_NAM   "VIA Networking Velocity Family Gigabit Ethernet Adapter Driver"
#define GETB_ADAPTER_NAM    "VIA Networking Velocity Family Gigabit Ethernet Adapter"

#ifndef MAJOR_VERSION
#define MAJOR_VERSION       1
#endif

#ifndef MINOR_VERSION
#define MINOR_VERSION       11
#endif

#ifndef GETB_VERSION
#define GETB_VERSION        "1.11"
#endif

#define RX_BUF_SIZE_DEFAULT (2*1024)



#define KFREE(x)            kfree((x))

#define MAX_UINTS           8
#define OPTION_DEFAULT      { [0 ... MAX_UINTS-1] = -1}

#define REV_ID_VT6110       (0)
#define DEVICE_ID_VT6110    (0x3119)
#define VIA_VENDOR_ID       (0x1106)
#define PCI_ANY_ID          (0xFFFF)


/*
 * register space access macros
 */
#define CSR_WRITE_STREAM_4(sc, reg, val)	\
	bus_space_write_stream_4(sc->mem_tag, sc->mem_hdl, reg, val)
#define CSR_WRITE_4(sc, reg, val)	\
	bus_space_write_4(sc->mem_tag, sc->mem_hdl, reg, val)
#define CSR_WRITE_2(sc, reg, val)	\
	bus_space_write_2(sc->mem_tag, sc->mem_hdl, reg, val)
#define CSR_WRITE_1(sc, reg, val)	\
	bus_space_write_1(sc->mem_tag, sc->mem_hdl, reg, val)

#define CSR_READ_4(sc, reg)		\
	bus_space_read_4(sc->mem_tag, sc->mem_hdl, reg)
#define CSR_READ_2(sc, reg)		\
	bus_space_read_2(sc->mem_tag, sc->mem_hdl, reg)
#define CSR_READ_1(sc, reg)		\
	bus_space_read_1(sc->mem_tag, sc->mem_hdl, reg)

#define CSR_SETBIT_1(sc, reg, x)	\
	CSR_WRITE_1(sc, reg, CSR_READ_1(sc, reg) | (x))
#define CSR_SETBIT_2(sc, reg, x)	\
	CSR_WRITE_2(sc, reg, CSR_READ_2(sc, reg) | (x))
#define CSR_SETBIT_4(sc, reg, x)	\
	CSR_WRITE_4(sc, reg, CSR_READ_4(sc, reg) | (x))

#define CSR_CLRBIT_1(sc, reg, x)	\
	CSR_WRITE_1(sc, reg, CSR_READ_1(sc, reg) & ~(x))
#define CSR_CLRBIT_2(sc, reg, x)	\
	CSR_WRITE_2(sc, reg, CSR_READ_2(sc, reg) & ~(x))
#define CSR_CLRBIT_4(sc, reg, x)	\
	CSR_WRITE_4(sc, reg, CSR_READ_4(sc, reg) & ~(x))

#define CSR_SCBIT_1(sc, reg, x, m)	\
	CSR_WRITE_1(sc, reg, (CSR_READ_1(sc, reg) & ~(m)) | (x))
#define CSR_SCBIT_2(sc, reg, x, m)	\
	CSR_WRITE_2(sc, reg, (CSR_READ_2(sc, reg) & ~(m)) | (x))
#define CSR_SCBIT_4(sc, reg, x, m)	\
	CSR_WRITE_4(sc, reg, (CSR_READ_4(sc, reg) & ~(m)) | (x))


#undef readb
#undef readw
#undef readl
#undef writeb
#undef writew
#undef writel

#define readb(sc, reg)   CSR_READ_1(sc, reg)
#define readw(sc, reg)   CSR_READ_2(sc, reg)
#define readl(sc, reg)   CSR_READ_4(sc, reg)

#define writeb(sc, d, reg)   CSR_WRITE_1(sc, reg, (d))
#define writew(sc, d, reg)   CSR_WRITE_2(sc, reg, (d))
#define writel(sc, d, reg)   CSR_WRITE_4(sc, reg, (d))


#define BYTE_REG_BITS_ON(sc,x,reg)       CSR_SETBIT_1(sc, reg, x)
#define WORD_REG_BITS_ON(sc,x,reg)       CSR_SETBIT_2(sc, reg, x)
#define DWORD_REG_BITS_ON(sc,x,reg)      CSR_SETBIT_4(sc, reg, x)

#define BYTE_REG_BITS_OFF(sc,x,reg)      CSR_CLRBIT_1(sc, reg, x)
#define WORD_REG_BITS_OFF(sc,x,reg)      CSR_CLRBIT_2(sc, reg, x)
#define DWORD_REG_BITS_OFF(sc,x,reg)     CSR_CLRBIT_4(sc, reg, x)

#define BYTE_REG_BITS_IS_ON(sc,x,reg)    (CSR_READ_1(sc, reg) & (x))
#define WORD_REG_BITS_IS_ON(sc,x,reg)    (CSR_READ_2(sc, reg) & (x))
#define DWORD_REG_BITS_IS_ON(sc,x,reg)   (CSR_READ_4(sc, reg) & (x))

#define BYTE_REG_BITS_SET(sc,x,m,reg)    CSR_SCBIT_1(sc, reg, x, m)
#define WORD_REG_BITS_SET(sc,x,m,reg)    CSR_SCBIT_2(sc, reg, x, m)
#define DWORD_REG_BITS_SET(sc,x,m,reg)   CSR_SCBIT_4(sc, reg, x, m)

#define VAR_USED(p)     do { (p)=(p); } while (0)

#define udelay(x)       DELAY((x))
#define mdelay(x)       DELAY(1000*(x))


/* for BSD version compatibility */
#if __FreeBSD_version >= 500000
#define IFM_1000_TX       IFM_1000_T
#endif


#endif /* __IF_GETB_CFG_H__ */
